# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-16 09:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0006_emailmessage_emailsendrecord_weixinserviceaccesstoken'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailmessage',
            name='title',
            field=models.CharField(default='aa', max_length=180, verbose_name='\u90ae\u4ef6\u6807\u9898'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='emailmessage',
            name='to_user',
            field=models.TextField(help_text='\u53d1\u9001\u7ed9\u591a\u4eba\u65f6\uff0c\u7528\uff1b\u9694\u79bb\u5f00', null=True, verbose_name='\u53d1\u9001\u7ed9'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-06 11:51
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_message', '0004_auto_20181206_1915'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sendrecord',
            options={'ordering': ['-sent_at'], 'permissions': (('view_message_records', 'Can view message records'),)},
        ),
        migrations.RenameField(
            model_name='message',
            old_name='need_replay',
            new_name='need_reply',
        ),
        migrations.RemoveField(
            model_name='message',
            name='is_admin_show',
        ),
        migrations.RemoveField(
            model_name='message',
            name='is_user_show',
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_by',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='done_by_user', to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-05 13:08
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0002_auto_20181205_2103'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='to_user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_to_user', to=settings.AUTH_USER_MODEL, verbose_name='\u53d1\u9001\u7ed9'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import unicode_literals

import json
from django.utils import timezone
from django.shortcuts import render, reverse, redirect
from django.core.urlresolvers import reverse_lazy
from django.utils.decorators import method_decorator
from django.contrib.auth import get_user_model
from django.core.mail import EmailMultiAlternatives
from django.conf import settings

from .decorators import cls_decorator, func_decorator
from django.views.generic import ListView, DetailView, TemplateView
from django.db.models import Q, Sum, Count
from django.http import HttpResponse
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from .models import Message, SendRecord
from .forms import MessageForm, RecordChangeDoneForm, RecordSearchForm, SendRecordForm
from .utils import get_user_name, JSONResponse
from .exports import send_message
from .signals import send_message_signal

User = get_user_model()


# Create your views here.
# =======course=======
def test(request):
    from exports import send_message
    from django.contrib.auth.models import User
    user = User.objects.all().first()
    res = send_message(to_user=None, from_user=user, message_identity='course_alert', title='test', url=None)
    print(res)
    return HttpResponse('OK')


@method_decorator(cls_decorator(cls_name='MessageList'), name='dispatch')
class MessageList(ListView):
    template_name = 'bee_django_message/message/message_list.html'
    context_object_name = 'message_list'
    paginate_by = 20
    queryset = Message.objects.all()


@method_decorator(cls_decorator(cls_name='MessageDetail'), name='dispatch')
class MessageDetail(DetailView):
    model = Message
    template_name = 'bee_django_message/message/message_detail.html'
    context_object_name = 'message'


@method_decorator(cls_decorator(cls_name='MessageCreate'), name='dispatch')
class MessageCreate(CreateView):
    model = Message
    form_class = MessageForm
    template_name = 'bee_django_message/message/message_form.html'


@method_decorator(cls_decorator(cls_name='MessageUpdate'), name='dispatch')
class MessageUpdate(UpdateView):
    model = Message
    form_class = MessageForm
    template_name = 'bee_django_message/message/message_form.html'


@method_decorator(cls_decorator(cls_name='MessageDelete'), name='dispatch')
class MessageDelete(DeleteView):
    model = Message
    success_url = reverse_lazy('bee_django_message:message_list')

    def get(self, request, *args, **kwargs):
        return self.http_method_not_allowed(request, *args, **kwargs)


# 后台显示消息记录
class RecordList(ListView):
    template_name = 'bee_django_message/record/message_record_list.html'
    context_object_name = 'record_list'
    paginate_by = 20
    queryset = None

    def get_message(self):
        message_id = self.kwargs["message_id"]
        if message_id in [0, '0', None]:
            return None
        message = Message.objects.get(id=message_id)
        return message

    def search(self):
        is_done = self.request.GET.get("is_done")
        has_from_user = self.request.GET.get("has_from_user")
        message = self.get_message()
        self.queryset = SendRecord.objects.filter(message=message)

        is_done_value = None
        if not is_done in ["0", 0, None, ""]:
            if is_done in [1, "1"]:
                is_done_value = True
            elif is_done in [-1, "-1"]:
                is_done_value = False
            self.queryset = self.queryset.filter(is_done=is_done_value)
        if not has_from_user in ["0", 0, None, ""]:
            self.queryset = self.queryset.filter(from_user__isnull=False)
        return self.queryset

    def get_queryset(self):
        return self.search()

    def get_context_data(self, **kwargs):
        context = super(RecordList, self).get_context_data(**kwargs)
        message = self.get_message()
        is_done = self.request.GET.get("is_done")
        context['message'] = message
        context['search_form'] = RecordSearchForm({"is_done": is_done})
        return context


class RecordDetail(DetailView):
    model = SendRecord
    template_name = 'bee_django_message/record/record_detail.html'
    context_object_name = 'record'


class RecordCreate(CreateView):
    model = SendRecord
    form_class = SendRecordForm
    template_name = 'bee_django_message/record/record_create.html'

    def form_valid(self, form):
        form.instance.from_user = self.request.user
        return super(RecordCreate, self).form_valid(form)

    def get_success_url(self):
        return reverse_lazy('bee_django_message:record_list', kwargs={"message_id": 0})+"?has_from_user=1"


class RecordCustomDetail(RecordDetail):
    template_name = 'bee_django_message/record/record_custom_detail.html'


# 修改后台显示的消息
class RecordUpdate(UpdateView):
    model = SendRecord
    form_class = RecordChangeDoneForm
    template_name = 'bee_django_message/record/record_change_done.html'

    def get_success_url(self):
        return reverse_lazy('bee_django_message:record_detail', kwargs=self.kwargs)

    def get_context_data(self, **kwargs):
        record = SendRecord.objects.get(id=self.kwargs["pk"])
        context = super(RecordUpdate, self).get_context_data(**kwargs)
        context['record'] = record
        return context

    def form_valid(self, form):
        record = form.instance
        record.is_done = True
        record.done_at = timezone.now()
        record.done_by = self.request.user
        if record.message.need_reply:
            send_message(to_user=record.from_user, title=record.get_reply_title(), info=record.get_reply_info())
        return super(RecordUpdate, self).form_valid(form)


# 发送记录
@method_decorator(cls_decorator(cls_name='UserRecordList'), name='dispatch')
class CustomUserRecordList(ListView):
    template_name = 'bee_django_message/record/custom_user_record_list.html'
    context_object_name = 'record_list'
    paginate_by = 20
    queryset = None

    def get_user(self):
        user_id = self.kwargs["user_id"]
        if user_id in [None, "0"]:
            return None
        user = User.objects.get(id=user_id)
        return user

    def get_queryset(self):
        user = self.get_user()
        self.queryset = SendRecord.objects.filter(to_user=user)
        return self.queryset

    def get_context_data(self, **kwargs):
        user = self.get_user()
        context = super(CustomUserRecordList, self).get_context_data(**kwargs)
        context['user'] = user
        return context


@method_decorator(cls_decorator(cls_name='UserRecordClick'), name='dispatch')
class UserRecordClick(TemplateView):
    def post(self, request, *args, **kwargs):
        record_id = request.POST.get("record_id")
        record = SendRecord.objects.get(id=record_id)
        record.is_view = True
        record.save()
        return JSONResponse(json.dumps({"url": record.url}, ensure_ascii=False))


class UserRecordAllClick(TemplateView):
    def post(self, request, *args, **kwargs):
        user_id = request.POST.get("user_id")
        try:
            user = User.objects.get(id=user_id)
            pass
        except:
            res = {"error": 1, "message": "参数错误"}
            return JSONResponse(json.dumps(res, ensure_ascii=False))
        record_list = SendRecord.objects.filter(to_user=user, is_view=False)
        for record in record_list:
            record.is_view = True
            record.save()
        res = {"error": 0, "message": "操作成功"}
        return JSONResponse(json.dumps(res, ensure_ascii=False))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-20 08:27
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0008_auto_20191119_1623'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='info',
            field=bee_django_richtext.custom_fields.RichTextField(app_name='bee_django_message', blank=True, emotion=False, image_max_size=2, img=True, model_name='SendRecord', null=True, text_min_length=5, undo_redo=False, verbose_name='\u5185\u5bb9'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-06 11:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0003_auto_20181205_2108'),
    ]

    operations = [
        migrations.RenameField(
            model_name='message',
            old_name='is_done',
            new_name='need_done',
        ),
        migrations.RenameField(
            model_name='message',
            old_name='is_replay',
            new_name='need_replay',
        ),
        migrations.AlterField(
            model_name='sendrecord',
            name='done_info',
            field=models.TextField(blank=True, help_text='\u5982\u8bbe\u7f6e\u4e3a\u3010\u53d1\u9001\u56de\u6267\u3011\uff0c\u586b\u5199\u540e\u4f1a\u7ed9\u53d1\u9001\u4eba\u53d1\u7ad9\u5185\u4fe1', null=True, verbose_name='\u5904\u7406\u7ed3\u679c'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django.conf.urls import include, url
from . import views
app_name = 'bee_django_message'
urlpatterns = [
    url(r'^test$', views.test, name='test'),
    url(r'^$', views.MessageList.as_view(), name='index'),
    # =======消息类型========
    url(r'^message/list/$', views.MessageList.as_view(), name='message_list'),
    url(r'^message/detail/(?P<pk>[0-9]+)/$', views.MessageDetail.as_view(), name='message_detail'),

    url(r'^message/add/$', views.MessageCreate.as_view(), name='message_add'),
    url(r'^message/update/(?P<pk>[0-9]+)/$', views.MessageUpdate.as_view(), name='message_update'),
    url(r'^message/delete/(?P<pk>[0-9]+)/$', views.MessageDelete.as_view(), name='message_delete'),



    # =======发送记录========
    url(r'^record/list/(?P<message_id>[0-9]+)/$', views.RecordList.as_view(), name='record_list'),
    url(r'^record/detail/(?P<pk>[0-9]+)/$', views.RecordDetail.as_view(), name='record_detail'),
    url(r'^record/add/$', views.RecordCreate.as_view(), name='record_add'),

    url(r'^record/update/(?P<pk>[0-9]+)/$', views.RecordUpdate.as_view(), name='record_update'),

    # =====发送给用户的消息======
    url(r'^custom/user/record/list/(?P<user_id>[0-9]+)/$', views.CustomUserRecordList.as_view(), name='custom_user_record_list'),
    url(r'^record/custom/detail/(?P<pk>[0-9]+)/$', views.RecordCustomDetail.as_view(), name='record_custom_detail'),
    url(r'^user/record/click/$', views.UserRecordClick.as_view(), name='user_record_click'),
    url(r'^user/record/all/click/$', views.UserRecordAllClick.as_view(), name='user_records_all_click'),

    # =======发送微信========
    # url(r'^send/wx/message/$', views.send_wx_message, name='send_wx_message'),
    # url(r'^send/email/$', views.send_email, name='send_email'),
]


#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms
from django.contrib.auth import get_user_model
from .models import Message, SendRecord

User = get_user_model()

# ===== course contract======
class MessageForm(forms.ModelForm):
    class Meta:
        model = Message
        fields = ['identity', 'name', "info", 'need_done', "need_reply"]


class SendRecordForm(forms.ModelForm):
    class Meta:
        model = SendRecord
        fields = ['to_user', 'title', "info"]


class RecordChangeDoneForm(forms.ModelForm):
    class Meta:
        model = SendRecord
        fields = ['done_info']


class RecordSearchForm(forms.Form):
    is_done_choices = ((0, "全部"), (1, "已处理"), (-1, "未处理"))
    is_done = forms.ChoiceField(choices=is_done_choices, label='', required=False)

    # class Meta:
    #     model = SendRecord
    #     fields = ['is_done']



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-12 10:20
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_message', '0005_auto_20181206_1951'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u6d88\u606f\u540d\u79f0')),
                ('to_user', models.CharField(max_length=180)),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bf4\u660e')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_message_email',
            },
        ),
        migrations.CreateModel(
            name='EmailSendRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, null=True)),
                ('content', models.TextField(null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('email_message', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='email_message', to='bee_django_message.EmailMessage')),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='email_send_record_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_message_email_record',
            },
        ),
        migrations.CreateModel(
            name='WeixinServiceAccessToken',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.CharField(max_length=180)),
                ('appid', models.CharField(max_length=180)),
                ('appsecrect', models.CharField(max_length=180)),
                ('alias', models.CharField(max_length=180)),
                ('expires', models.IntegerField()),
                ('gettime', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'db_table': 'bee_django_message_weixin_service_access_token',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-05 13:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='is_done',
            field=models.BooleanField(default=False, help_text='\u5982\u679c\u4e0d\u9700\u540e\u53f0\u663e\u793a\uff0c\u5219\u4e0d\u7528\u586b\u5199', verbose_name='\u662f\u5426\u9700\u8981\u540e\u53f0\u5904\u7406'),
        ),
        migrations.AddField(
            model_name='message',
            name='is_replay',
            field=models.BooleanField(default=False, help_text='\u5982\u679c\u4e0d\u9700\u5904\u7406\uff0c\u5219\u4e0d\u7528\u586b\u5199', verbose_name='\u540e\u53f0\u5904\u7406\u540e\u662f\u5426\u56de\u590d'),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_at',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='done_info',
            field=models.TextField(blank=True, null=True, verbose_name='\u5904\u7406\u7ed3\u679c'),
        ),
        migrations.AddField(
            model_name='sendrecord',
            name='is_done',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u5904\u7406\u8fc7'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
from __future__ import unicode_literals

import urllib2, json, datetime
from django.db import models
from django.core.urlresolvers import reverse
from django.conf import settings
from django.contrib.auth.models import User
from django.utils import timezone
from django.core.mail import EmailMultiAlternatives


from bee_django_richtext.custom_fields import RichTextField

# Create your models here.
# def get_user_table():
#     return settings.AUTH_USER_MODEL


# 站内信
class Message(models.Model):
    name = models.CharField(max_length=180, verbose_name='消息名称')
    info = models.CharField(max_length=180, null=True, blank=True, verbose_name='说明')
    need_done = models.BooleanField(default=False, verbose_name='是否需要后台处理', help_text='如果不需后台显示，则不用填写')
    need_reply = models.BooleanField(default=False, verbose_name='后台处理后是否回复', help_text='如果不需处理，则不用填写')
    identity = models.CharField(max_length=180, null=True, verbose_name='标识符', unique=True, help_text='此字段唯一')

    class Meta:
        app_label = 'bee_django_message'
        db_table = 'bee_django_message'
        ordering = ["id"]

    def __unicode__(self):
        return ("Message->name:" + self.name)

    def get_absolute_url(self):
        return reverse('bee_django_message:message_list')

    def get_done(self):
        if self.need_done:
            return "是"
        else:
            return '否'

    def get_replay(self):
        if self.need_reply:
            return "是"
        else:
            return '否'

# 站内信
class SendRecord(models.Model):
    from_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bee_message_from_user', verbose_name='来自',
                                  null=True)
    to_user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bee_message_to_user', verbose_name='发送给',
                                null=True)
    message = models.ForeignKey('bee_django_message.Message', related_name='record_message', null=True)
    title = models.CharField(max_length=180, verbose_name='主题')
    info = RichTextField(null=True, verbose_name='内容', blank=True,app_name='bee_django_message',model_name="SendRecord",img=True)
    is_view = models.BooleanField(default=False, verbose_name='是否看过')
    sent_at = models.DateTimeField(auto_now_add=True, verbose_name='发送时间')
    url = models.CharField(max_length=180, null=True, verbose_name='点击后跳转到的页面')
    is_done = models.BooleanField(default=False, verbose_name='是否处理过')
    done_info = models.TextField(verbose_name='处理结果', null=True, blank=True, help_text='如设置为【发送回执】，填写后会给发送人发站内信')
    done_at = models.DateTimeField(null=True)
    done_by = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='done_by_user', null=True)

    class Meta:
        app_label = 'bee_django_message'
        db_table = 'bee_django_message_record'
        ordering = ["-sent_at"]
        permissions = (("view_message_records", "Can view message records"),)

    def __unicode__(self):
        return ("SendRecord->title:" + self.title)

    def get_absolute_url(self):
        return reverse('bee_django_message:record_list',kwargs={"message_id":0})

    def get_reply_title(self):
        return u'您发送的提醒已受理：' + self.done_info

    def get_reply_info(self):
        return None

    # def get_reply_url(self):
    #     return reverse("bee_django_message:record_custom_detail", kwargs={"pk": self.pk})

    @classmethod
    def send_message(cls,from_user=None, to_user=None, message_identity=None, title="", info="", url=""):
        message = None
        if message_identity:
            try:
                message = Message.objects.get(identity=message_identity)
            except:
                message = None
        try:
            record = cls()
            record.from_user = from_user
            record.to_user = to_user
            record.message = message
            record.title = title
            record.info = info
            record.url = url
            record.save()
            return True
        except Exception as e:
            print('bee_django_message->send_message->error:' + e.__str__())
            return False

# 邮件
class EmailMessage(models.Model):
    name = models.CharField(max_length=180, verbose_name='消息名称')
    to_user = models.TextField(verbose_name="发送给", help_text='发送给多人时，用；隔离开', null=True)
    title = models.CharField(max_length=180, verbose_name='邮件标题')
    info = models.CharField(max_length=180, null=True, blank=True, verbose_name='说明')
    identity = models.CharField(max_length=180, verbose_name='标识符', unique=True, help_text='此字段唯一')

    class Meta:
        app_label = 'bee_django_message'
        db_table = 'bee_django_message_email'
        ordering = ["id"]

    def __unicode__(self):
        return ("EmailMessage->name:" + self.name)


# 邮件
class EmailSendRecord(models.Model):
    email_message = models.ForeignKey('bee_django_message.EmailMessage', related_name='email_message')
    user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='email_send_record_user', null=True)
    title = models.CharField(max_length=180, null=True)
    content = models.TextField(null=True)
    created_at = models.DateTimeField(auto_now_add=True)

    class Meta:
        app_label = 'bee_django_message'
        db_table = 'bee_django_message_email_record'
        ordering = ["-created_at"]

    def __unicode__(self):
        return ("EmailSendRecord->to_user:" + self.to_user)

    @classmethod
    def get_course_notify_context(cls, ucs):
        if not hasattr(settings, "EMAIL_CONFIG"):
            return None, 'settings没有配置'
        try:
            email_message = EmailMessage.objects.get(identity='course_notify')
        except:
            return None, '没有符合的EmailMessage'
        user = ucs.user
        html_context = "<p>" + email_message.title
        html_context += "<p>缦客：" + user.get_sn() + user.get_user_name()

        assistant = user.get_assistant()
        if assistant:
            html_context += "<p>助教：" + assistant.get_sn().__str__() + assistant.get_user_name()
        html_context += "<p>课程：" + ucs.user_course.course.name
        html_context += "<p>课件：" + ucs.section.name
        html_context += "<p>要求时间：" + (ucs.section.video_length_req + ucs.teacher_add_mins).__str__() + "分钟"
        html_context += "<p>练习时间：" + (ucs.work_time - ucs.minus_mins).__str__() + "分钟"
        # html_context += "<p><a href='http://manxuetang.com/course/editUserCourseSection?id=" + user.id.__str__() + "&user_course_id=" + us.user_course.id.__str__() + "'>前往（需登录）</a><p>"
        return html_context, '成功'

    @classmethod
    def send_course_notify_email(cls, ucs):
        if not hasattr(settings, "EMAIL_CONFIG"):
            return None, 'settings没有配置'
        try:
            email_message = EmailMessage.objects.get(identity='course_notify')
        except:
            return None, '没有符合的EmailMessage'
        to_mail_list = ";".split(email_message.to_user)
        if len(to_mail_list) < 1:
            return False
        try:
            form_email = settings.EMAIL_CONFIG.host_user
            subject = settings.EMAIL_CONFIG.subject_prefix + email_message.title
            html_content = cls().get_course_notify_context(ucs)
            msg = EmailMultiAlternatives(subject, email_message.title, form_email, to_mail_list)
            msg.attach_alternative(html_content, 'text/html')
            msg.send()
            record = cls()
            record.email_message = email_message
            record.title = subject
            record.content = html_content
            record.save()
        except Exception as e:
            print("=" * 10 + "send_email:" + e.__str__())
            return None,'错误'



# 微信
class WeixinService(models.Model):
    class Meta:
        db_table = 'bee_django_message'
        app_label = 'bee_django_message_weixin_service'

    @classmethod
    def send_wx_message(cls, template_identity, openId, first=None, keyword1=None, keyword2=None, keyword3=None,
                        keyword4=None, keyword5=None, remark=None, url=None):
        if not hasattr(settings, "WEIXIN_SERVICE_CONFIG"):
            return
        wx_template_obj = settings.WEIXIN_SERVICE_CONFIG.WX_Template
        if template_identity == 'course_notify_assistant':
            template_id = wx_template_obj.course_up_req
        elif template_identity == 'course_pass':
            template_id = wx_template_obj.course_pass
        else:
            return
        token = WeixinServiceAccessToken().get_token(scene=1)
        # print(token)
        weixinUrl = "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=" + token
        data = json.dumps({"touser": openId,
                           "template_id": template_id,
                           "url": url,
                           "topcolor": "#FF0000",
                           "data": {
                               "first": {
                                   "value": first,
                                   "color": "#173177"
                               },
                               "keyword1": {
                                   "value": keyword1,
                                   "color": "#173177"
                               },
                               "keyword2": {
                                   "value": keyword2,
                                   "color": "#173177"
                               },
                               "keyword3": {
                                   "value": keyword3,
                                   "color": "#173177"
                               },
                               "keyword4": {
                                   "value": keyword4,
                                   "color": "#173177"
                               },
                               "keyword5": {
                                   "value": keyword5,
                                   "color": "#173177"
                               },
                               "remark": {
                                   "value": remark,  # "请安排好时间",
                                   "color": "#FF0000"
                               }
                           }
                           })
        # print(data)
        req = urllib2.urlopen(weixinUrl, data)
        res = req.read()
        # print('=========================')
        # print(res)
        return json.loads(res)


class WeixinServiceAccessToken(models.Model):
    token = models.CharField(max_length=180)
    appid = models.CharField(max_length=180)
    appsecret = models.CharField(max_length=180)
    alias = models.CharField(max_length=180)
    expires = models.IntegerField()
    gettime = models.DateTimeField(auto_now_add=True)
    scene = models.IntegerField(choices=((1,'微信服务号'),(2,'crm砍价小程序'),),default=1,verbose_name='使用场景')

    class Meta:
        app_label = 'bee_django_message'
        db_table = 'bee_django_message_weixin_service_access_token'

    def __unicode__(self):
        return self.token

    @classmethod
    def create_token(cls,scene):
        if scene == 1:
            if not hasattr(settings, "WEIXIN_SERVICE_CONFIG"):
                return None
            appid = settings.WEIXIN_SERVICE_CONFIG.appid
            app_secret = settings.WEIXIN_SERVICE_CONFIG.app_secret
        elif scene == 2:
            a = settings.WEIXINAPP_GIFT_CONFIG
            if not hasattr(settings, "WEIXINAPP_GIFT_CONFIG"):
                return None
            appid = settings.WEIXINAPP_GIFT_CONFIG.appid
            app_secret = settings.WEIXINAPP_GIFT_CONFIG.app_secret
        else:
            return None
        url = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + app_secret
        res = urllib2.urlopen(url).read()
        obj = json.loads(res)
        # 保存
        t = cls()
        t.token = obj["access_token"]
        t.expires = obj["expires_in"]
        t.gettime = timezone.now()
        t.appid = appid
        t.appsecret = app_secret
        t.save()
        return t

    @classmethod
    def get_token(cls,scene):
        tokens = cls.objects.filter(scene=scene).order_by("-gettime")
        if not tokens.exists():
            t = cls.create_token(scene)
            return t.token

        old_token = tokens.first()
        expire_dt = old_token.gettime + datetime.timedelta(seconds=old_token.expires)
        if old_token.token and timezone.now() < expire_dt:
            return old_token.token
        else:
            t = cls.create_token(scene)
            return t.token



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-19 08:23
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0007_auto_20190816_1757'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sendrecord',
            name='info',
            field=bee_django_richtext.custom_fields.RichTextField(blank=True, default='', image_max_size=1, null=True, verbose_name='\u5185\u5bb9'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django.conf import settings
from django.contrib.auth.models import User

from .models import Message, SendRecord
from utils import get_message

# def get_user(request):
#     return get_login_user(request)




# 发送消息，返回结果
def send_message(from_user=None, to_user=None, message_identity=None, title="", info="", url=""):
    try:
        record = SendRecord()
        record.from_user = from_user
        record.to_user = to_user
        record.message = get_message(message_identity)
        record.title = title
        record.info = info
        record.url = url
        record.save()
        return True
    except Exception as e:
        print('bee_django_message->send_message->error:' + e.__str__())
        return False


# 消息状态改为已读信息
# def change_message_stutas(message_record_id):
#     try:
#         record = SendRecord.objects.get(id=message_record_id)
#         record.is_view = True
#         record.save()
#     except:
#         return False
#
# # django前台显示本地时间
# def filter_local_datetime(_datetime):
#     return _datetime


#!/usr/bin/env python
# -*- coding:utf-8 -*-

from django.conf import settings

# 微信公众号
class WeixinService():
    appid = 'wxd9c89c4c644961ff'
    app_secret = '66d12e8d8696f461ea866739b1a905fc'

    class Template():
        bind = "udMZmNX3qcu5CBT1Q2GxW0KozvcfPAXjb_ZkRIkdEfQ"  # to all：绑定通知
        course_up_req = 'hjv8iLMzlUtLSeZw495jDG01FsgaWvofCAoyI6H0fHc'  # to助教：提醒事项-到达要求
        course_pass = 'TLtYaznjdQOAWJHFWF0BmnsicJn-2UFyS0fy0I4vgQI'  # to学生：课程通过提醒

# CRM中砍价小程序 文暄社
class WEIXINAPP_GIFT():
    appid = 'wxc0a58ce74b898212'
    app_secret = '64de157ddadeca2e45ee0ea32c676f8e'

# 邮件配置
class Email():
    backend = 'django.core.mail.backends.smtp.EmailBackend'
    use_tls = True
    host = 'smtp.exmail.qq.com' # SMTP地址
    port = 587 # SMTP端口
    host_user = 'zhangyue@zhenpuedu.com'
    host_password = 'Pbu883' #邮箱密码
    subject_prefix = '[缦学堂]'
    default_from_emial= '958206195@qq.com'
    server_email= '958206195@qq.com'  # The email address that error messages come from, such as those sent to ADMINS and MANAGERS.
    admins = (('bee', '958206195@qq.com'))


def init_settings():
    # 初始化
    # 微信公众号
    if hasattr(settings,"MESSAGE_WEIXIN_SERVICE") and settings.MESSAGE_WEIXIN_SERVICE==True:
        settings.WEIXIN_SERVICE_CONFIG=WeixinService()
    # crm中微信砍价小程序
    if hasattr(settings,"MESSAGE_WEIXINAPP_GIFT") and settings.MESSAGE_WEIXINAPP_GIFT==True:
        settings.WEIXINAPP_GIFT_CONFIG=WEIXINAPP_GIFT()
    # 邮件配置
    if hasattr(settings,"MESSAGE_EMAIL") and settings.MESSAGE_EMAIL==True:
        settings.EMAIL_CONFIG=Email


#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django import template
from django.conf import settings

# from bee_django_message.exports import filter_local_datetime
from bee_django_message.utils import get_user_name

register = template.Library()


# 本地化时间
# @register.filter
# def local_datetime(_datetime):
#     return filter_local_datetime(_datetime)


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)

# 获取学生姓名，及详情链接
@register.filter
def get_name_detail(user, show_detail=True):
    if not user:
        return ''
    user_name = get_user_name(user)
    if not show_detail:
        return user_name
    if settings.USER_DETAIL_EX_LINK:
        link = "<a href='" + settings.USER_DETAIL_EX_LINK + user.id.__str__() + "/'>" + user_name + "</a>"
    else:
        link = user_name
    return link

@register.filter
def get_send_name(user):
    if not user:
        return settings.MESSAGE_DEFAULT_NAME
    return get_user_name(user)


#!/usr/bin/env python
# -*- coding:utf-8 -*-

__author__ = 'bee'
import json
from django.conf import settings
from django.apps import apps
from django.contrib.auth.models import User
from django.http import HttpResponse

from .models import Message, SendRecord,WeixinServiceAccessToken


class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")


def get_message(identity=None):
    message = None
    if identity:
        try:
            message = Message.objects.get(identity=identity)
        except:
            message = None
    return message


# 获取自定义user的自定义name
def get_user_name(user):
    try:
        return getattr(user, settings.USER_NAME_FIELD)
    except:
        return None





# 获取学生未读信息的数量
def get_user_new_message_count(user, message_identity=None):
    if not user or not user.is_authenticated():
        return 0
    message = get_message(message_identity)
    records = SendRecord.objects.filter(to_user=user, is_view=False)
    if message:
        records = records.filter(message=message)
    return records.count()






# context
def get_context_user_new_message_count(request):
    context = {
        'context_user_new_message_count': get_user_new_message_count(request.user),
    }
    return context



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-04 09:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_message', '0009_auto_20191120_1627'),
    ]

    operations = [
        migrations.RenameField(
            model_name='weixinserviceaccesstoken',
            old_name='appsecrect',
            new_name='appsecret',
        ),
        migrations.AddField(
            model_name='weixinserviceaccesstoken',
            name='scene',
            field=models.IntegerField(choices=[(1, '\u5fae\u4fe1\u670d\u52a1\u53f7'), (2, 'crm\u780d\u4ef7\u5c0f\u7a0b\u5e8f')], default=1, verbose_name='\u4f7f\u7528\u573a\u666f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-18 07:10
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180, verbose_name='\u6d88\u606f\u540d\u79f0')),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u8bf4\u660e')),
                ('is_user_show', models.BooleanField(default=False, verbose_name='\u5b66\u751f\u9875\u662f\u5426\u663e\u793a')),
                ('is_admin_show', models.BooleanField(default=False, verbose_name='\u7ba1\u7406\u9875\u662f\u5426\u663e\u793a')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_message',
            },
        ),
        migrations.CreateModel(
            name='SendRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u4e3b\u9898')),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u5185\u5bb9')),
                ('is_view', models.BooleanField(default=False, verbose_name='\u662f\u5426\u770b\u8fc7')),
                ('sent_at', models.DateTimeField(auto_now_add=True, verbose_name='\u53d1\u9001\u65f6\u95f4')),
                ('url', models.CharField(max_length=180, null=True, verbose_name='\u70b9\u51fb\u540e\u8df3\u8f6c\u5230\u7684\u9875\u9762')),
                ('from_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_from_user', to=settings.AUTH_USER_MODEL, verbose_name='\u6765\u81ea')),
                ('message', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='record_message', to='bee_django_message.Message')),
                ('to_user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bee_message_to_user', to=settings.AUTH_USER_MODEL, verbose_name='\u53d1\u9001\u7ed9')),
            ],
            options={
                'ordering': ['-sent_at'],
                'db_table': 'bee_django_message_record',
            },
        ),
    ]
